
From: Andreas Gruenbacher <agruen@suse.de>

ext[23]_get_acl will return an error when reading the attribute fails or
out-of-memory occurs.  Catch this case.

Signed-off-by: Andreas Gruenbacher <agruen@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/ext2/acl.c |    2 ++
 25-akpm/fs/ext3/acl.c |    2 ++
 2 files changed, 4 insertions(+)

diff -puN fs/ext2/acl.c~fix-acl-oops fs/ext2/acl.c
--- 25/fs/ext2/acl.c~fix-acl-oops	2005-04-06 01:16:21.000000000 -0700
+++ 25-akpm/fs/ext2/acl.c	2005-04-06 01:16:21.000000000 -0700
@@ -283,6 +283,8 @@ ext2_check_acl(struct inode *inode, int 
 {
 	struct posix_acl *acl = ext2_get_acl(inode, ACL_TYPE_ACCESS);
 
+	if (IS_ERR(acl))
+		return PTR_ERR(acl);
 	if (acl) {
 		int error = posix_acl_permission(inode, acl, mask);
 		posix_acl_release(acl);
diff -puN fs/ext3/acl.c~fix-acl-oops fs/ext3/acl.c
--- 25/fs/ext3/acl.c~fix-acl-oops	2005-04-06 01:16:21.000000000 -0700
+++ 25-akpm/fs/ext3/acl.c	2005-04-06 01:16:21.000000000 -0700
@@ -286,6 +286,8 @@ ext3_check_acl(struct inode *inode, int 
 {
 	struct posix_acl *acl = ext3_get_acl(inode, ACL_TYPE_ACCESS);
 
+	if (IS_ERR(acl))
+		return PTR_ERR(acl);
 	if (acl) {
 		int error = posix_acl_permission(inode, acl, mask);
 		posix_acl_release(acl);
_
